/*
** Module   : SessionListener.java
** Abstract : defines event notifications for users of the network
**
** Copyright (c) 2007-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ---------------------------- Description ----------------------------
** 001 GES 20070111   @31796 First version which supports initialization
**                           and termination notifications.
** 002 ECF 20071112   @35889 Removed initialize method. Refactoring of
**                           sessions and queues and network bootstrapping
**                           has made this notification obsolete.
** 003 OM  20131018          Added session initialization callback.
*/

package com.goldencode.p2j.net;

/**
 * Defines an event notification framework for users of network sessions.
 */
public interface SessionListener
{
   /**
    * This callback will be called after the security context has been set up and is valid for
    * the life of this thread and before any of the client code it will be executed.
    * <p>
    * Implement this method if you some work must be done from the thread that has the proper
    * security context set up.
    *
    * @param    session
    *           The session that is starting.
    */
   public void initialize(Session session);

   /**
    * This method is called when the session is ending.  This is useful for
    * cleaning up resources or state.
    *
    * @param    session
    *           The session that is ending.
    */
   public void terminate(Session session);
}
