/*
** Module   : SecurityManagerSecurityOps.java
** Abstract : Progress 4GL compatible security interface that does not use the _User metatables.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------------------Description---------------------------------
** 001 OM  20130913 First version, implementing the basic four methods: get/set with and without
**                  the logical database name.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.security.SecurityManager;

/**
 * Progress 4GL compatible security interface that does not use the _User meta-table.
 * This is the first P2J approach that uses the SecurityManager for enforcing security policy.
 * <p>
 * This is the default handler for SecurityOps for user related methods.
 */
public class SecurityManagerSecurityOps
implements CustomSecurityOps
{
   /**
    * Returns the userid associated with the current user from the SecurityManager instance.
    *
    * @return   The current user context's userid or the empty string in the case of any problem.
    */
   public String getUserId()
   {
      SecurityManager sm = SecurityManager.getInstance();
      return (sm != null) ? sm.getUserId() : SecurityOps.BLANK_USER;
   }

   /**
    * Returns the userid associated with the current user of the given logical database.
    *
    * @param    dbname
    *           Logical database name.
    *
    * @return   Always return empty string as the SecurityManager is not database dependent.
    */
   public String getUserIdFromDB(String dbname)
   {
      return SecurityOps.BLANK_USER;
   }

   /**
    * Authenticates the user for specified DB connection. Checks if the user login account match
    * the corresponding record of the _User table of the database. If there are multiple database
    * connections or none is connected, an error is issued.
    *
    * @param    userid
    *           The name of the user to set as UserID.
    * @param    password
    *           The users password.
    *
    * @return   Always return <code>true</code> as the SecurityManager is not database dependent.
    */
   public boolean setUserId(String userid, String password)
   {
      return true;
   }

   /**
    * Authenticates the user for specified DB connection. Checks if the user login account match
    * the corresponding record of the _User table of the database.  If the specified database
    * is not connected, an error is issued.
    *
    * @param    userid
    *           The name of the user to set as UserID.
    * @param    password
    *           The users password.
    * @param    dbname
    *           Logical database name.
    *
    * @return   Always return <code>true</code> as the SecurityManager is not database dependent.
    */
   public boolean setUserId(String userid, String password, String dbname)
   {
      return true;
   }

   /**
    * Check the access level for a database. This will query the _User table and return the value.
    *
    * @param   db
    *          The database to query.
    *
    * @return  The access level to specified database.
    */
   @Override
   public int getAuthLevel(String ldbname)
   {
      return SecurityOps.FREE_ACCESS;
   }
}
